@@ -25,24 +25,20 @@
 #include <qtextdocument.h>
 #include <qurlquery.h>
 
-#include <kapplication.h>
-#include <kcmdlineargs.h>
-#include <k4aboutdata.h>
-
 #include <kshell.h>
 
-#include <kcomponentdata.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kconfig.h>
 #include <kconfiggroup.h>
 #include <kbookmark.h>
 #include <kbookmarkmanager.h>
 #include <kimagecache.h>
-#include <kdebug.h>
+#include <qdebug.h>
 #include <kfileplacesmodel.h>
 #include <solid/device.h>
 #include <solid/deviceinterface.h>
 #include <ktoolinvocation.h>
+#include <QCoreApplication>
 
 using namespace KIO;
 
@@ -153,7 +149,7 @@ void BookmarksProtocol::flattenTree( const KBookmarkGroup &folder )
     next = tree.next(bm);
 
     if (bm.isGroup() && bm.parentGroup().hasParent()) {
-      kDebug() << "moving " << bm.text() << " from " << bm.parentGroup().fullText() << " to " << prev.parentGroup().text() << endl;
+      //qDebug() << "moving " << bm.text() << " from " << bm.parentGroup().fullText() << " to " << prev.parentGroup().text() << endl;
 
       bm.setFullText("| " + bm.parentGroup().fullText() + " > " + bm.fullText());
       tree.moveBookmark(bm, prev);
@@ -206,14 +202,11 @@ void BookmarksProtocol::get( const QUrl& url )
 
 extern "C" int Q_DECL_EXPORT kdemain(int argc, char **argv)
 {
-  K4AboutData about("kio_bookmarks", 0, ki18n("My bookmarks"), "0.2.2");
-  about.addLicense(K4AboutData::License_GPL_V2);
-  about.addAuthor(ki18n("Xavier Vello"), ki18n("Initial developer"), "xavier.vello@gmail.com", QByteArray());
-  KCmdLineArgs::init(&about);
-  KApplication app;
+  QCoreApplication app(argc, argv); 
+  app.setApplicationName(QLatin1String("kio_ldap"));
 
   if (argc != 4) {
-      kError() << "Usage: kio_bookmarks protocol domain-socket1 domain-socket2";
+      qCritical() << "Usage: kio_bookmarks protocol domain-socket1 domain-socket2";
       exit(-1);
   }
 
